@@ -1,22 +1,24 @@
 # coding: utf-8
-"""musdl: Pure Python score downloader for
-Musescore."""
+"""Pure Python score downloader for Musescore."""
 
 import argparse
+import io
 import re
 import logging
 import os
 import pathlib
 import tempfile
-import subprocess
 import sys
 
 import bs4 as bsoup
-import fpdf
 import requests
 
+from svglib import svglib
+import reportlab.pdfgen.canvas as rlab_canvas
+import reportlab.graphics.renderPDF as rlab_pdf
+
 __author__ = "Ong Yong Xin"
-__version__ = "2.1.2"
+__version__ = "2.2.0"
 __copyright__ = "(c) 2020 Ong Yong Xin"
 __license__ = "MIT"
 
@@ -28,7 +30,6 @@ RE_BASEURL = re.compile(
 
 # only here for backwards compatibility
 ALLOWED_FORMATS = frozenset(["mid", "mp3", "mxl", "pdf"])
-PDF_RES = [210, 297]
 
 # logging stuff
 _log = logging.getLogger("musdl")
@@ -60,39 +61,6 @@ def sanitize_filename(name):
     return re.sub("_{2,}", "_", sanitised)
 
 
-def _find_imagemagick():
-    args = ["which", "magick"]
-
-    if os.name == "nt":
-        args[0] = "where"
-
-    try:
-        return subprocess.check_output(args).strip()
-    except subprocess.CalledProcessError:
-        return None
-
-
-def _convert_svg_to_png(svg_path, png_path, wh):
-
-    width, height = wh
-    magick_path = _find_imagemagick()
-
-    if magick_path is None:
-        raise RuntimeError("imagemagick not found: please install first")
-
-    args = [
-        magick_path,
-        svg_path,
-        "-size", f"{width}x{height}",
-        f"PNG8:{png_path}"  # 8-bit, fpdf does noy support 16-bit pngs
-    ]
-
-    try:
-        subprocess.run(args, check=True)
-    except subprocess.CalledProcessError:
-        raise RuntimeError("failed to run imagemagick: exited with non-zero status code")
-
-
 class Score(object):
     """A music score on Musescore.
 
@@ -147,18 +115,17 @@ class Score(object):
         return f"{self.baseurl}score.{format}"
 
     def _as_pdf(self):
-        # pdf is made of a few images
-        pdf = fpdf.FPDF()
-        width, height = PDF_RES
-
-        tempdir = tempfile.TemporaryDirectory()
-        temp = pathlib.Path(tempdir.name)
+        temp = tempfile.TemporaryDirectory()
+        tempdir = pathlib.Path(temp.name)
+        
+        buffer = io.BytesIO()
+        pdf = rlab_canvas.Canvas(buffer)
+        
         page = 0
 
         while True:
-            svg = temp / f"{page}.svg"
-            png = temp / f"{page}.png"
-
+            svg = tempdir / f"{page}.svg"
+            
             _log.info(f"downloading page ({page}.svg)")
             svg_data = requests.get(f"{self.baseurl}score_{page}.svg")
 
@@ -169,22 +136,22 @@ class Score(object):
             elif not svg_data.ok:
                 raise DownloadError(f"could not get score pdf page #{page}: {e}")
 
-            with open(svg, "wb") as f:
+            with svg.open(mode="wb") as f:
                 f.write(svg_data.content)
 
-            _log.info("converting svg to png")
-            _convert_svg_to_png(svg, png, PDF_RES)
+            _log.info("rendering svg")
+            drawing = svglib.svg2rlg(str(svg))
 
             _log.info(f"adding {page}.png to pdf")
-            pdf.add_page()
-            pdf.image(str(png), x=0, y=0, w=width, h=height)
+            rlab_pdf.draw(drawing, pdf, 0, 0)
+            pdf.showPage()
 
             page += 1
 
         _log.info(f"building pdf file")
-        data = pdf.output(dest="S").encode("latin-1")
-        tempdir.cleanup()
-        return data
+        pdf.save()
+        temp.cleanup()
+        return buffer.getvalue()
 
     def download(self, format):
         """Get the score's data.
